#!/bin/sh
#############################################################################
#
#  This script populates the already created database
#
#  History:
#  Anders Nilsson, VV, 06/25/04, Created
#
##########################################################################

## Get local directory ##

WORK=`pwd`

echo Using database "$GISRS_DATABASE"
echo

## Make sure NOHRSC_systems is executable **

PROGRAM=NOHRSC_systems

## Check local directory ##

if [ -f $WORK/$PROGRAM ]
then
   PROGRAM=$WORK/$PROGRAM
else

   which $PROGRAM 1>/dev/null

   if [ $? -ne 0 ]
   then

     echo Error: the NOHRSC_systems executable can't be found.
     echo \(It is not located within the current directory, and,
     echo  its parent directory isn't found in the PATH system variable.\)
     exit

   fi
     
fi

## Check for existence of database install directory? ##

if [ -d $WORK/database_install ]
then 
   echo Restoring database from $WORK/database_install
else
   echo Error: Can\'t find the database_install directory
   exit
fi

## Create tables ##
## This should be able to handle if tables already exist ##

$PROGRAM -install "$WORK/database_install"

## Make sure successful execution ##

if [ $? -eq 0 ]
then

## Get listing of layers to restore ##

   LAYERS=`ls -d *.*`

## Loop through and restore layers ##

   for LAYER in $LAYERS ; do

## See if product file exists ##

      PRODUCT=$WORK/$LAYER/product

##    If is not present, skip ##

      if [ -f "$PRODUCT" ]
      then

##       Get layername from product file ##

         LAYERNAME=`cut -d \| -f 3 $PRODUCT`

##       Check for layer existence ##

         $PROGRAM -exists "$LAYERNAME"

##       If already exists, skip ##

         if [ $? -ne 0 ]
         then 

            echo
            echo Restoring layer $LAYERNAME...

##          Restore layer ##

            $PROGRAM -restore "$WORK/$LAYER" NULL NULL NULL

            if [ $? -ne 0 ]
            then
               echo
               echo Installation incomplete.
               break
            fi     

         else

            echo Layer $LAYERNAME already exists.
 
         fi

      fi

   done

   echo
   echo Installation complete.

fi


